export default interface IUnityInstanceParameters {
    /**
     * The url to the build data file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @type {string}
     */
    dataUrl: string;
    /**
     * The url to the framework file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @type {string}
     */
    frameworkUrl: string;
    /**
     * The url to the unity code file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @type {string}
     */
    codeUrl: string;
    /**
     * The url where the streaming assets can be found. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @type {string}
     */
    streamingAssetsUrl?: string;
    /**
     * The applications company name.
     * @type {string}
     */
    companyName?: string;
    /**
     * The applications product name.
     * @type {string}
     */
    productName?: string;
    /**
     * The applications product version.
     * @type {string}
     */
    productVersion?: string;
    /**
     * Unity Module injection.
     * @type {Object}
     */
    modules?: Object;
    /**
     * The Canvas can appear too blurry on retina screens. The devicePixelRatio
     * determines how much extra pixel density should be added to allow for a
     * sharper image.
     * @type {number}
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Window/devicePixelRatio
     */
    devicePixelRatio?: number;
    /**
     * When disabling the match WebGL to canvas size flag, the canvas allows for
     * client side customization of the WebGL canvas target size instead of
     * requiring it to always match 1:1 with the High DPI CSS size of the canvas.
     * Supported since Unity 2021.1b
     * @requires Unity_2021_1b
     * @type {boolean}
     * @see https://issuetracker.unity3d.com/issues/webgl-builds-dont-allow-separate-control-on-canvas-render-buffer-size
     */
    matchWebGLToCanvasSize?: boolean;
}
//# sourceMappingURL=unity-instance-parameters.d.ts.map